@@ -3,10 +3,10 @@ from dataclasses import dataclass
 import pytest
 
 from xcept import Exception_
-from xcept.warnings import MissingFieldWarning, UnknownFieldWarning
+from xcept.warnings import MissingTemplateWarning, MissingFieldWarning, UnknownFieldWarning
 
 
-@pytest.mark.parametrize(
+MISSING_REPLACEMENT_FIELD_TEST_DATA = (
     ("template",),
     (
         ("",),
@@ -15,16 +15,7 @@ from xcept.warnings import MissingFieldWarning, UnknownFieldWarning
         ("message",)
     )
 )
-def test_template_with_missing_replacement_fields(template: str) -> None:
-    @dataclass
-    class TestException(Exception_):
-        test_field: str
-
-    with pytest.warns(MissingFieldWarning):
-        TestException(template, test_field="test_value")
-
-
-@pytest.mark.parametrize(
+UNKNOWN_REPLACEMENT_FIELD_TEST_DATA = (
     ("template",),
     (
         # Positional field without index
@@ -47,7 +38,29 @@ def test_template_with_missing_replacement_fields(template: str) -> None:
         ("{test_field} {unknown_field.attribute}",),
     )
 )
-def test_template_with_unknown_replacement_fields(template: str) -> None:
+
+
+def test_missing_template() -> None:
+    @dataclass
+    class TestException(Exception_):
+        pass
+
+    with pytest.warns(MissingTemplateWarning):
+        TestException(None)
+
+
+@pytest.mark.parametrize(*MISSING_REPLACEMENT_FIELD_TEST_DATA)
+def test_missing_replacement_fields(template: str) -> None:
+    @dataclass
+    class TestException(Exception_):
+        test_field: str
+
+    with pytest.warns(MissingFieldWarning):
+        TestException(template, test_field="test_value")
+
+
+@pytest.mark.parametrize(*UNKNOWN_REPLACEMENT_FIELD_TEST_DATA)
+def test_unknown_replacement_fields(template: str) -> None:
     @dataclass
     class TestException(Exception_):
         test_field: str
